/*
 *  identitymanager.h  -  manages the list of email identities
 *  Program:  kalarm
 *  Copyright (C) 2004 by David Jarvie <software@astrojar.org.uk>
 *  This is a modified version of the KDEPIM file of the same name,
 *  Copyright (c) 2002 Marc Mutz <mutz@kde.org>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  51 Franklin Steet, Fifth Floor, Boston, MA 02110-1301, USA.
 */

#ifndef KPIM_IDENTITYMANAGER_H
#define KPIM_IDENTITYMANAGER_H

#include <qvaluelist.h>
#include <qstringlist.h>
#include <qcstring.h>
#include <dcopobject.h>

#include "identity.h"

class KConfig;

namespace KPIM {

class Identity;

class IdentityManager : public QObject, virtual public DCOPObject
{
		Q_OBJECT
		K_DCOP
	public:
		typedef QValueList<Identity>::Iterator Iterator;
		typedef QValueList<Identity>::ConstIterator ConstIterator;

		IdentityManager(bool readonly = true, QObject* parent = 0, const char* name = 0);
		~IdentityManager();
		QStringList     identities() const;
		const Identity& identityForName(const QString& identityName) const;
		const Identity& defaultIdentity() const;
		ConstIterator   begin() const   { return mIdentities.begin(); }
		ConstIterator   end() const     { return mIdentities.end(); }

	k_dcop:
		void slotIdentitiesChanged(QCString appId, QCString objId);

	signals:
		void changed();

	private:
		void            readConfig();

		QValueList<Identity> mIdentities;
		KConfig*             mConfig;
		bool                 mOldConfig;
};

} // namespace

#endif // KPIM_IDENTITYMANAGER_H
